@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "sequed" "20251219.1858"
-  "Major mode for FASTA format DNA alignments."
+(define-package "sequed" "20260219.2234"
+  "Major mode for FASTA and phylip/bpp DNA alignments."
   '((emacs "25.2"))
   :url "https://github.com/brannala/sequed"
-  :commit "d8b76c47db7de52118ab9217dac7d3308d4df9cc"
-  :revdesc "d8b76c47db7d"
+  :commit "0156c71a163b7d55b2a8b198eab0be3de9dc229d"
+  :revdesc "0156c71a163b"
   :authors '(("Bruce Rannala" . "brannala@ucdavis.edu"))
   :maintainers '(("Bruce Rannala" . "brannala@ucdavis.edu")))
